
base_template_file = '/usr/local/lib/python3.10/dist-packages/bigsansar/templates/'

def read_template(filename):
    with open(filename, 'r') as file:
        return file.read()

def render(template, **kwargs):
     # Replace placeholders with values
    for key, value in kwargs.items():
        template = template.replace('{{ ' + key + ' }}', str(value))
    return template


base_template = read_template(base_template_file + 'base.html')


from bigsansar.contrib.views import about_page, contact_page, index_page


path_handlers = {
        "": index_page,
        "/dashboard": index_page,
        "/about": about_page,
        "/contact": contact_page,
    }


from bigsansar.contrib.cgi_base import read_template, base_template_file,base_template,render


def index_page():
   
    template =  read_template(base_template_file + 'admin/login.html')
    content =  render(template, title="Index Page", content="Welcome to the Index Page!")
    return render(base_template, title="My Page", body=content)


def about_page():
    return "<h1>About Us</h1><p>This is the About Us page.</p>"

def contact_page():
    return "<h1>Contact Us</h1><p>You can reach us at contact@example.com.</p>"



def not_found_page():
    return read_template(base_template_file + 'templates/404.html')


#!/usr/bin/python3

import os
from bigsansar.contrib.urls import path_handlers
from bigsansar.contrib.views import not_found_page
import cgitb

cgitb.enable()

def main():
    
    # Set the content type to HTML
    print("Content-type: text/html\n")

     # Get the path from the environment
    path = os.environ.get('PATH_INFO', '')
    # Define the URL path handlers

    # Call the appropriate handler based on the path
    page_content = path_handlers.get(path, not_found_page)()

    # Print the HTML response
    print(page_content)

if __name__ == "__main__":
    main()
